@@ -137,12 +137,12 @@ class Client(object):
             # No content so its obviously not paginated
             return resp
 
-        # if resp._content is a bytes object, decode it so we can loads it as json
-        if isinstance(resp_content, bytes):
-            resp_content = resp_content.decode('utf-8')
-
         # Load the json so we can use the data as python objects
-        content = json.loads(resp_content)
+        content = json.loads(
+            resp_content.decode('utf-8')
+            if isinstance(resp_content, bytes)
+            else resp_content)
+
         if 'pagination' not in content:
             # Result is not paginated
             return resp
@@ -153,7 +153,7 @@ class Client(object):
             content['data'].extend(prev_data)
             # If resp._content was is a bytes object, only set it as a bytes object
             if isinstance(resp_content, bytes):
-                resp._content = json.dumps(content).decode('utf-8')
+                resp._content = json.dumps(content).encode('utf-8')
             else:
                 resp._content = json.dumps(content)
             return resp
